@@ -22,17 +22,17 @@ package org.apache.myfaces.component.search;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
-import javax.faces.FacesException;
-import javax.faces.component.ContextCallback;
-import javax.faces.component.NamingContainer;
-import javax.faces.component.UIComponent;
-import javax.faces.component.UIViewRoot;
-import javax.faces.component.search.ComponentNotFoundException;
-import javax.faces.component.search.SearchExpressionContext;
-import javax.faces.component.search.SearchExpressionHandler;
-import javax.faces.component.search.SearchExpressionHint;
-import javax.faces.component.search.SearchKeywordContext;
-import javax.faces.context.FacesContext;
+import jakarta.faces.FacesException;
+import jakarta.faces.component.ContextCallback;
+import jakarta.faces.component.NamingContainer;
+import jakarta.faces.component.UIComponent;
+import jakarta.faces.component.UIViewRoot;
+import jakarta.faces.component.search.ComponentNotFoundException;
+import jakarta.faces.component.search.SearchExpressionContext;
+import jakarta.faces.component.search.SearchExpressionHandler;
+import jakarta.faces.component.search.SearchExpressionHint;
+import jakarta.faces.component.search.SearchKeywordContext;
+import jakarta.faces.context.FacesContext;
 import org.apache.myfaces.shared.renderkit.html.util.SharedStringBuilder;
 
 /**
@@ -535,8 +535,8 @@ public class SearchExpressionHandlerImpl extends SearchExpressionHandler
             // At this point if the algorithm hasn't returned and the topExpression does not have any separator char
             // we need to do the search backward using findComponent.
             if (target == null 
-                    && searchExpressionContext.getSource() == previous 
-                    && (topExpression.indexOf(separatorChar) == -1) )
+                    && searchExpressionContext.getSource() == previous
+                    && (topExpression.indexOf(separatorChar + "@") == -1) ) // updated for MYFACES-4695
             {
                 UIComponent baseNC = previous.getNamingContainer();
                 if (baseNC != null && baseNC.getParent() != null)
@@ -562,7 +562,12 @@ public class SearchExpressionHandlerImpl extends SearchExpressionHandler
                     }
                 }
             }
-        
+            
+            if (target == null && nextExpression == null)
+            {
+                return;
+            }
+
             topCallback.invokeContextCallback(facesContext, previous);
         }
         
@@ -857,4 +862,4 @@ public class SearchExpressionHandlerImpl extends SearchExpressionHandler
         return tokens.toArray(new String[tokens.size()]);
     }
 
-}
\ No newline at end of file
+}
