@@ -20,19 +20,17 @@ package org.apache.myfaces.shared.renderkit.html;
 
 import org.apache.myfaces.shared.renderkit.RendererUtils;
 
-import javax.faces.component.UIComponent;
-import javax.faces.component.UIViewRoot;
-import javax.faces.component.html.HtmlPanelGroup;
-import javax.faces.context.FacesContext;
-import javax.faces.context.ResponseWriter;
+import jakarta.faces.component.UIComponent;
+import jakarta.faces.component.UIViewRoot;
+import jakarta.faces.component.html.HtmlPanelGroup;
+import jakarta.faces.context.FacesContext;
+import jakarta.faces.context.ResponseWriter;
 import java.io.IOException;
+import java.util.List;
+import java.util.Map;
+import jakarta.faces.component.behavior.ClientBehavior;
+import org.apache.myfaces.shared.renderkit.html.util.ResourceUtils;
 
-/**
- * @author Martin Marinschek
- * @version $Revision: 1187701 $ $Date: 2011-10-22 12:21:54 +0000 (Sat, 22 Oct 2011) $
- *          <p/>
- *          $Log: $
- */
 public class HtmlGroupRendererBase
         extends HtmlRenderer 
 {
@@ -43,6 +41,15 @@ public class HtmlGroupRendererBase
         return true;
     }
 
+    @Override
+    public void decode(FacesContext context, UIComponent component)
+    {
+        // Check for npe
+        super.decode(context, component);
+        
+        HtmlRendererUtils.decodeClientBehaviors(context, component);
+    }
+
     public void encodeBegin(FacesContext context, UIComponent component)
             throws IOException
     {
@@ -70,23 +77,51 @@ public class HtmlGroupRendererBase
         {
             layoutElement = HTML.DIV_ELEM;
         }
+        
+        Map<String, List<ClientBehavior>> behaviors = panelGroup.getClientBehaviors();
+        if (behaviors != null && !behaviors.isEmpty())
+        {
+            ResourceUtils.renderDefaultJsfJsInlineIfNecessary(context, writer);
+        }
 
-        if(component.getId()!=null && !component.getId().startsWith(UIViewRoot.UNIQUE_ID_PREFIX))
+        if( (!behaviors.isEmpty()) || 
+                (component.getId()!=null && !component.getId().startsWith(UIViewRoot.UNIQUE_ID_PREFIX)))
         {
             span = true;
 
             writer.startElement(layoutElement, component);
 
-            HtmlRendererUtils.writeIdIfNecessary(writer, component, context);
+            //HtmlRendererUtils.writeIdIfNecessary(writer, component, context);
+            writer.writeAttribute(HTML.ID_ATTR, component.getClientId(context), null);
 
+            long commonPropertiesMarked = 0L;
             if (isCommonPropertiesOptimizationEnabled(context))
             {
-                CommonPropertyUtils.renderCommonPassthroughProperties(writer, 
-                        CommonPropertyUtils.getCommonPropertiesMarked(component), component);
+                commonPropertiesMarked = CommonPropertyUtils.getCommonPropertiesMarked(component);
+                CommonPropertyUtils.renderCommonPassthroughPropertiesWithoutEvents(writer, 
+                        commonPropertiesMarked, component);
             }
             else
             {
-                HtmlRendererUtils.renderHTMLAttributes(writer, component, HTML.COMMON_PASSTROUGH_ATTRIBUTES);
+                HtmlRendererUtils.renderHTMLAttributes(writer, component, HTML.UNIVERSAL_ATTRIBUTES);
+            }
+            if (behaviors.isEmpty() && isCommonPropertiesOptimizationEnabled(context))
+            {
+                CommonPropertyUtils.renderEventProperties(writer, 
+                        commonPropertiesMarked, component);
+            }
+            else
+            {
+                if (isCommonEventsOptimizationEnabled(context))
+                {
+                    CommonEventUtils.renderBehaviorizedEventHandlers(context, writer, 
+                           commonPropertiesMarked,
+                           CommonEventUtils.getCommonEventsMarked(component), component, behaviors);
+                }
+                else
+                {
+                    HtmlRendererUtils.renderBehaviorizedEventHandlers(context, writer, component, behaviors);
+                }
             }
         }
         else
