@@ -21,19 +21,21 @@ package org.apache.myfaces.view.facelets;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import jakarta.faces.FactoryFinder;
 
-import javax.faces.component.UIComponent;
-import javax.faces.component.UIViewRoot;
-import javax.faces.component.UniqueIdVendor;
-import javax.faces.context.FacesContext;
-import javax.faces.view.AttachedObjectHandler;
-import javax.faces.view.EditableValueHolderAttachedObjectHandler;
-import javax.faces.view.facelets.FaceletContext;
+import jakarta.faces.component.UIComponent;
+import jakarta.faces.component.UIViewRoot;
+import jakarta.faces.component.UniqueIdVendor;
+import jakarta.faces.component.visit.VisitContextFactory;
+import jakarta.faces.context.FacesContext;
+import jakarta.faces.view.AttachedObjectHandler;
+import jakarta.faces.view.EditableValueHolderAttachedObjectHandler;
+import jakarta.faces.view.facelets.FaceletContext;
 
 /**
  * @since 2.0.1
- * @author Leonardo Uribe (latest modification by $Author: lu4242 $)
- * @version $Revision: 1424975 $ $Date: 2012-12-21 15:41:27 +0000 (Fri, 21 Dec 2012) $
+ * @author Leonardo Uribe (latest modification by $Author$)
+ * @version $Revision$ $Date$
  */
 abstract public class FaceletCompositionContext
 {
@@ -358,7 +360,7 @@ abstract public class FaceletCompositionContext
      * Used to clean up all unused relocatable components on the root component.
      *
      * @since 2.0.17 2.1.11
-     * @param component
+     * @param root
      *            UIComponent to finalize (root component)
      */
     public void finalizeRelocatableResourcesForDeletion(UIViewRoot root)
@@ -448,6 +450,27 @@ abstract public class FaceletCompositionContext
         return null;
     }
     
+    /**
+     * Start a new unique id section, which means a new counter is used to
+     * generate unique ids to components, but appending a base to the
+     * new counter.
+     * 
+     * @since 2.2.0
+     * @return
+     */
+    public String startComponentUniqueIdSection(String base)
+    {
+        return null;
+    }
+    
+    /**
+     * @since 2.2.0
+     * @param base 
+     */
+    public void endComponentUniqueIdSection(String base)
+    {
+    }
+    
     /**
      * Generate a unique id that will be used later to derive a unique id per tag
      * by FaceletContext.generateUniqueId(). This generator ensures uniqueness per
@@ -541,14 +564,13 @@ abstract public class FaceletCompositionContext
      * Increment the unique id without construct it.
      * 
      * since 2.1.7, 2.0.13
-     * @return 
      */
     public void incrementUniqueId()
     {
     }
 
     /**
-     * Check if the view
+     * Check if the facelet is building view metadata
      * 
      * since 2.1.7, 2.0.13
      * @return 
@@ -563,7 +585,6 @@ abstract public class FaceletCompositionContext
      * Call this method to indicate a f:metadata section is about to be processed
      * 
      * since 2.1.7, 2.0.13
-     * @return 
      */
     public void startMetadataSection()
     {
@@ -573,7 +594,6 @@ abstract public class FaceletCompositionContext
      * Call this method to indicate f:metadata section has been already processed
      * 
      * since 2.1.7, 2.0.13
-     * @return 
      */
     public void endMetadataSection()
     {
@@ -624,4 +644,69 @@ abstract public class FaceletCompositionContext
     {
         return 0;
     }
+    
+    public boolean isDynamicCompositeComponentHandler()
+    {
+        return false;
+    }
+    
+    public void setDynamicCompositeComponentHandler(boolean value)
+    {
+    }
+    
+    public void pushDynamicComponentSection(String baseKey)
+    {
+    }
+    
+    public void popDynamicComponentSection()
+    {
+    }
+    
+    /**
+     * Check if the algorithm is applying a dynamic component and the current component
+     * is the top level one. This is necessary to avoid remove/add the component under
+     * a refresh and in that way change the position of the component in the tree. Remember
+     * facelets algorithm removes/add components to sort the components under a refresh, but
+     * in this case, it is up to the user to put the component in the tree, so the idea is
+     * do not make interference with the user's code. Note if the dynamic content is wrapped
+     * by a generated panel, the top level component is the wrapper itself, which has no 
+     * attached tag handler.
+     * 
+     * @since 2.2
+     * @return 
+     */
+    public boolean isDynamicComponentTopLevel()
+    {
+        return false;
+    }
+    
+    public void setDynamicComponentTopLevel(boolean value)
+    {
+    }
+    
+    /**
+     * Indicate if the current facelet section is a dynamic component section,
+     * which means it was added to the component tree using vdl.createComponent(...);
+     * 
+     * @since 2.2
+     * @return 
+     */
+    public boolean isDynamicComponentSection()
+    {
+        return false;
+    }
+    
+    public UIViewRoot getViewRoot(FacesContext facesContext)
+    {
+        return facesContext.getViewRoot();
+    }
+    
+    public void setViewRoot(UIViewRoot root)
+    {
+    }
+    
+    public VisitContextFactory getVisitContextFactory()
+    {
+        return (VisitContextFactory)FactoryFinder.getFactory(FactoryFinder.VISIT_CONTEXT_FACTORY);
+    }
 }
