@@ -23,13 +23,13 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Stack;
 
-import javax.el.ELException;
-import javax.faces.application.FacesMessage;
-import javax.faces.view.facelets.CompositeFaceletHandler;
-import javax.faces.view.facelets.FaceletHandler;
-import javax.faces.view.facelets.Tag;
-import javax.faces.view.facelets.TagAttribute;
-import javax.faces.view.facelets.TagException;
+import jakarta.el.ELException;
+import jakarta.faces.application.FacesMessage;
+import jakarta.faces.view.facelets.CompositeFaceletHandler;
+import jakarta.faces.view.facelets.FaceletHandler;
+import jakarta.faces.view.facelets.Tag;
+import jakarta.faces.view.facelets.TagAttribute;
+import jakarta.faces.view.facelets.TagException;
 
 import org.apache.myfaces.shared.renderkit.html.HTML;
 import org.apache.myfaces.view.facelets.el.ELText;
@@ -37,7 +37,7 @@ import org.apache.myfaces.view.facelets.el.ELText;
 /**
  * 
  * @author Jacob Hookom
- * @version $Id: TextUnit.java 1730144 2016-02-12 23:41:41Z lu4242 $
+ * @version $Id$
  */
 final class TextUnit extends CompilationUnit
 {
@@ -93,7 +93,7 @@ final class TextUnit extends CompilationUnit
     {
         this.flushBufferToConfig(true);
 
-        if (this.children.size() == 0)
+        if (this.children.isEmpty())
         {
             return LEAF;
         }
@@ -384,92 +384,44 @@ final class TextUnit extends CompilationUnit
 
     protected void flushBufferToConfig(boolean child)
     {
+        this.flushTextBuffer(child);
 
-        // NEW IMPLEMENTATION
-        if (true)
+        int size = this.instructionBuffer.size();
+        if (size > 0)
         {
-
-            this.flushTextBuffer(child);
-
-            int size = this.instructionBuffer.size();
-            if (size > 0)
-            {
-                try
-                {
-                    String s = this.buffer.toString();
-                    if (child)
-                    {
-                        s = trimRight(s);
-                    }
-                    ELText txt = ELText.parse(s);
-                    if (txt != null)
-                    {
-                        if (compressSpaces)
-                        {
-                            // Use the logic behind the instructions to remove unnecessary instructions
-                            // containing only spaces, or recreating new ones containing only the necessary
-                            // spaces.
-                            size = compressSpaces(instructionBuffer, size);
-                        }
-                        Instruction[] instructions = (Instruction[]) this.instructionBuffer
-                                .toArray(new Instruction[size]);
-                        this.children.add(new UIInstructionHandler(this.alias, this.id, instructions, txt));
-                        this.instructionBuffer.clear();
-                    }
-
-                }
-                catch (ELException e)
-                {
-                    if (this.tags.size() > 0)
-                    {
-                        throw new TagException((Tag) this.tags.peek(), e.getMessage());
-                    }
-                    else
-                    {
-                        throw new ELException(this.alias + ": " + e.getMessage(), e.getCause());
-                    }
-                }
-            }
-
-            // KEEP THESE SEPARATE SO LOGIC DOESN'T GET FUBARED
-        }
-        else if (this.buffer.length() > 0)
-        {
-            String s = this.buffer.toString();
-            if (s.trim().length() > 0)
+            try
             {
+                String s = this.buffer.toString();
                 if (child)
                 {
                     s = trimRight(s);
                 }
-                if (s.length() > 0)
+                ELText txt = ELText.parse(s);
+                if (txt != null)
                 {
-                    try
+                    if (compressSpaces)
                     {
-                        ELText txt = ELText.parse(s);
-                        if (txt != null)
-                        {
-                            if (txt.isLiteral())
-                            {
-                                this.children.add(new UILiteralTextHandler(txt.toString()));
-                            }
-                            else
-                            {
-                                this.children.add(new UITextHandler(this.alias, txt));
-                            }
-                        }
-                    }
-                    catch (ELException e)
-                    {
-                        if (this.tags.size() > 0)
-                        {
-                            throw new TagException((Tag) this.tags.peek(), e.getMessage());
-                        }
-                        else
-                        {
-                            throw new ELException(this.alias + ": " + e.getMessage(), e.getCause());
-                        }
+                        // Use the logic behind the instructions to remove unnecessary instructions
+                        // containing only spaces, or recreating new ones containing only the necessary
+                        // spaces.
+                        size = compressSpaces(instructionBuffer, size);
                     }
+                    Instruction[] instructions = (Instruction[]) this.instructionBuffer
+                            .toArray(new Instruction[size]);
+                    this.children.add(new UIInstructionHandler(this.alias, this.id, instructions, txt));
+                    this.instructionBuffer.clear();
+                }
+
+            }
+            catch (ELException e)
+            {
+                if (this.tags.size() > 0)
+                {
+                    throw new TagException((Tag) this.tags.peek(), e.getMessage());
+                }
+                else
+                {
+                    throw new ELException(this.alias + ": " + e.getMessage(), e.getCause());
                 }
             }
         }
@@ -634,7 +586,7 @@ final class TextUnit extends CompilationUnit
             }
             else if (ins instanceof LiteralNonExcapedTextInstruction)
             {
-                text = ((LiteralTextInstruction)ins).getText();
+                text = ((LiteralNonExcapedTextInstruction)ins).getText();
                 instructionType = 2;
             }
             else if (ins instanceof LiteralXMLInstruction)
@@ -758,22 +710,6 @@ final class TextUnit extends CompilationUnit
         }
         return size;
     }
-
-    private static int getFirstTextCharLocationIgnoringSpacesTabsAndCarriageReturn(String text)
-    {
-        for (int i = 0; i < text.length(); i++)
-        {
-            if (Character.isWhitespace(text.charAt(i)))
-            {
-                continue;
-            }
-            else
-            {
-                return i;
-            }
-        }
-        return text.length();
-    }
     
     private static int getLastTextCharLocationIgnoringSpacesTabsAndCarriageReturn(String text)
     {
