@@ -87,6 +87,19 @@ public class SearchExpressionImplTest extends AbstractMyFacesRequestTestCase
                 searchContext, "@this:@parent:showName").get(0);
         Assert.assertEquals(componentId, "mainForm:showName");
 
+        componentId = facesContext.getApplication().getSearchExpressionHandler().resolveClientIds(
+                searchContext, "@form:inputOutsideForm").get(0);
+        Assert.assertEquals("mainForm:inputOutsideForm", componentId);
+  
+        try
+        {
+            facesContext.getApplication().getSearchExpressionHandler().resolveClientIds(searchContext, ":inputOutsideForm");
+            Assert.fail();
+        }
+        catch (ComponentNotFoundException e)
+        {
+        }
+
         componentId = facesContext.getApplication().getSearchExpressionHandler().resolveClientIds(
                 searchContext, "mainForm:table:0:baseText").get(0);
         Assert.assertEquals(componentId, "mainForm:table:0:baseText");
@@ -397,6 +410,24 @@ public class SearchExpressionImplTest extends AbstractMyFacesRequestTestCase
         Assert.assertFalse(handler.isPassthroughExpression(searchContextWithAjaxResolve, "@form:@child(0)"));
     }
 
+    @Test
+    public void testMyFaces4695() throws Exception
+    {
+        startViewRequest("/search2.xhtml");
+        processLifecycleExecute();
+        executeBeforeRender();
+        executeBuildViewCycle();
+
+        SearchExpressionContext searchContext = 
+                SearchExpressionContext.createSearchExpressionContext(facesContext, facesContext.getViewRoot().findComponent("form2:submit"));
+
+        SearchExpressionHandler handler = facesContext.getApplication().getSearchExpressionHandler();
+
+        Assert.assertEquals("form1:one", handler.resolveClientId(searchContext, "form1:one"));
+
+        processRemainingPhases();
+    }
+
     /*
     @Test
     public void testCompositeComponentExpression() throws Exception
