@@ -19,29 +19,29 @@
 package org.apache.myfaces.shared.renderkit.html;
 
 import java.io.IOException;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.logging.Logger;
 
-import javax.faces.application.FacesMessage;
-import javax.faces.component.UIComponent;
-import javax.faces.component.UIMessage;
-import javax.faces.component.UIViewRoot;
-import javax.faces.component.behavior.ClientBehavior;
-import javax.faces.component.behavior.ClientBehaviorHolder;
-import javax.faces.component.html.HtmlMessage;
-import javax.faces.context.FacesContext;
-import javax.faces.context.ResponseWriter;
+import jakarta.faces.application.FacesMessage;
+import jakarta.faces.component.UIComponent;
+import jakarta.faces.component.UIMessage;
+import jakarta.faces.component.UIViewRoot;
+import jakarta.faces.component.behavior.ClientBehavior;
+import jakarta.faces.component.behavior.ClientBehaviorHolder;
+import jakarta.faces.component.html.HtmlMessage;
+import jakarta.faces.component.search.SearchExpressionContext;
+import jakarta.faces.component.search.SearchExpressionHandler;
+import jakarta.faces.component.search.SearchExpressionHint;
+import jakarta.faces.context.FacesContext;
+import jakarta.faces.context.ResponseWriter;
 
 import org.apache.myfaces.shared.renderkit.JSFAttr;
 import org.apache.myfaces.shared.renderkit.RendererUtils;
-import org.apache.myfaces.shared.renderkit.html.util.JavascriptUtils;
 
-/**
- * @author Manfred Geiler (latest modification by $Author$)
- * @version $Revision$ $Date$
- */
 public abstract class HtmlMessageRendererBase
         extends HtmlRenderer
 {
@@ -87,8 +87,26 @@ public abstract class HtmlMessageRendererBase
             return;
         }
 
-        UIComponent forComponent = message.findComponent(forAttr);
-        if (forComponent == null)
+        //UIComponent forComponent = message.findComponent(forAttr);
+        //UIComponent forComponent = message.findComponent(forAttr);
+        //if (forComponent == null)
+        //{
+        //    log.severe("Could not render Message. Unable to find component '" 
+        //            + forAttr + "' (calling findComponent on component '" 
+        //            + message.getClientId(facesContext) 
+        //            + "'). If the provided id was correct, wrap the message and its " 
+        //            + "component into an h:panelGroup or h:panelGrid.");
+        //    return;
+        //}
+
+        //String clientId = forComponent.getClientId(facesContext);
+        SearchExpressionHandler searchExpressionHandler = facesContext.getApplication().getSearchExpressionHandler();
+        Set<SearchExpressionHint> expressionHints = new HashSet<SearchExpressionHint>();
+        expressionHints.add(SearchExpressionHint.IGNORE_NO_RESULT);
+        String clientId = searchExpressionHandler.resolveClientId(
+                SearchExpressionContext.createSearchExpressionContext(
+                        facesContext, message, expressionHints, null), forAttr);
+        if (clientId == null)
         {
             log.severe("Could not render Message. Unable to find component '" 
                     + forAttr + "' (calling findComponent on component '" 
@@ -98,8 +116,6 @@ public abstract class HtmlMessageRendererBase
             return;
         }
 
-        String clientId = forComponent.getClientId(facesContext);
-
         Iterator<FacesMessage> messageIterator = facesContext.getMessages(clientId);
         if (!messageIterator.hasNext())
         {
@@ -107,7 +123,7 @@ public abstract class HtmlMessageRendererBase
             if (alwaysRenderSpan)
             {
                 ResponseWriter writer = facesContext.getResponseWriter();
-                writer.startElement(HTML.SPAN_ELEM, null);
+                writer.startElement(HTML.SPAN_ELEM, message);
                 writer.writeAttribute(HTML.ID_ATTR, clientId + "_msgFor", null);
                 HtmlRendererUtils.renderHTMLStringAttribute(writer, message, JSFAttr.STYLE_ATTR, HTML.STYLE_ATTR);
                 HtmlRendererUtils.renderHTMLStringAttribute(writer, message, JSFAttr.STYLE_CLASS_ATTR, HTML.CLASS_ATTR);
@@ -179,8 +195,7 @@ public abstract class HtmlMessageRendererBase
     throws IOException
     {
         Map<String, List<ClientBehavior>> behaviors = null;
-        if (message instanceof ClientBehaviorHolder && JavascriptUtils.isJavascriptAllowed(
-                facesContext.getExternalContext()))
+        if (message instanceof ClientBehaviorHolder)
         {
             behaviors = ((ClientBehaviorHolder) message).getClientBehaviors();
         }
@@ -212,9 +227,23 @@ public abstract class HtmlMessageRendererBase
         String title = getTitle(message);
         boolean tooltip = isTooltip(message);
 
+        boolean showSummary = isShowSummary(message) && (summary != null);
+        boolean showDetail = isShowDetail(message) && (detail != null);
+        
         if (title == null && tooltip)
         {
-            title = summary;
+            if (showDetail)
+            {
+                title = detail;
+            }
+            else if (detail != null)
+            {
+                title = detail;
+            }
+            else
+            {
+                title = summary;
+            }
         }
 
         ResponseWriter writer = facesContext.getResponseWriter();
@@ -222,8 +251,7 @@ public abstract class HtmlMessageRendererBase
         boolean span = false;
 
         Map<String, List<ClientBehavior>> behaviors = null;
-        if (message instanceof ClientBehaviorHolder && JavascriptUtils.isJavascriptAllowed
-                (facesContext.getExternalContext()))
+        if (message instanceof ClientBehaviorHolder)
         {
             behaviors = ((ClientBehaviorHolder) message).getClientBehaviors();
             // If there is a behavior registered, force wrapSpan
@@ -245,8 +273,7 @@ public abstract class HtmlMessageRendererBase
             {
                 HtmlRendererUtils.writeIdIfNecessary(writer, message, facesContext);
             }
-            if (message instanceof ClientBehaviorHolder && JavascriptUtils.isJavascriptAllowed(
-                    facesContext.getExternalContext()))
+            if (message instanceof ClientBehaviorHolder)
             {
                 behaviors = ((ClientBehaviorHolder) message).getClientBehaviors();
                 if (behaviors.isEmpty() && isCommonPropertiesOptimizationEnabled(facesContext))
@@ -291,12 +318,14 @@ public abstract class HtmlMessageRendererBase
                     writer, message, HTML.SPAN_ELEM, HTML.STYLE_ATTR, style, span);
             span |= HtmlRendererUtils.renderHTMLAttributeWithOptionalStartElement(
                     writer, message, HTML.SPAN_ELEM, HTML.STYLE_CLASS_ATTR, styleClass, span);
+            // Remember if renderStyleAndStyleClass is true, it means style and styleClass
+            // are rendered on the outer tag, and in that sense, role attribute should
+            // be rendered there too.
+            span |= HtmlRendererUtils.renderHTMLAttributeWithOptionalStartElement(
+                    writer, message, HTML.ROLE_ATTR, HTML.ROLE_ATTR, 
+                    message.getAttributes().get(HTML.ROLE_ATTR), span);
         }
 
-
-        boolean showSummary = isShowSummary(message) && (summary != null);
-        boolean showDetail = isShowDetail(message) && (detail != null);
-
         if (showSummary && !(title == null && tooltip))
         {
             writer.writeText(summary, null);
